---
title: How to use CSS in your application
nav_title: CSS
description: Learn about the different ways to add CSS to your application, including CSS Modules, Global CSS, Tailwind CSS, and more.
related:
  title: Next Steps
  description: Learn more about the features mentioned in this page.
  links:
    - pages/guides/tailwind-v3-css
    - pages/guides/sass
    - pages/guides/css-in-js
source: app/getting-started/css
---

{/* DO NOT EDIT. The content of this doc is generated from the source above. To edit the content of this page, navigate to the source page in your editor. You can use the `<PagesOnly>Content</PagesOnly>` component to add content that is specific to the Pages Router. Any shared content should not be wrapped in a component. */}
